@@ -1,7 +1,7 @@
 from __future__ import annotations
 
+import bz2
 import logging
-import lzma
 import os
 import re
 from collections import Counter
@@ -109,14 +109,14 @@ class DocumentPickleRepository:
         self.file_path = dir_path / f'.{path_hash}.pdef'
 
     def save(self, docs: set[models.Document]):
-        with lzma.open(self.file_path, 'wb') as file:
+        with bz2.open(self.file_path, 'wb') as file:
             dump(docs, file)
 
     def list(self) -> set[models.Document]:
         if self.file_path.exists():
             log.info('Found preprocessing file. Deserializing...')
             try:
-                with lzma.open(self.file_path, 'rb') as file:
+                with bz2.open(self.file_path, 'rb') as file:
                     return load(file)
             except (UnpicklingError, EOFError):
                 log.warning(f"Could not deserialize preprocessing file, '{self.file_path.name}' seems to be corrupted.")
